==> netbeans_6.8.orig.tar.gz: netbeans-6.8/lib.profiler/test/qa-functional/src/org/netbeans/lib/profiler/tests/jfluid/ProfilerStableTestSuite.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Sun designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Sun in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.lib.profiler.tests.jfluid;

import junit.framework.Test;
import org.netbeans.junit.NbModuleSuite;

/**
 *
 * @author tester
 */
public class ProfilerStableTestSuite {
    public static Test suite() {
    return NbModuleSuite.create(
      NbModuleSuite.emptyConfiguration()
        .addTest(org.netbeans.lib.profiler.tests.jfluid.BasicTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.wireio.BasicTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.monitor.BasicTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.memory.BasicTest.class)
	    .addTest(org.netbeans.lib.profiler.tests.jfluid.memory.MemorySnapshotTest.class)
	    .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.class, org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.tests)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.class, org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.tests2)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.class, org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.tests3)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.CPUSnapshotTest.class)
	//.addTest(org.netbeans.lib.profiler.tests.jfluid.benchmarks.JbbTest.class)
	//.addTest(org.netbeans.lib.profiler.tests.jfluid.others.MeasureDiffsTest.class)
    );
  }


}

==> netbeans_7.0.1+dfsg1.orig.tar.gz: netbeans-7.0.1+dfsg1/lib.profiler/test/qa-functional/src/org/netbeans/lib/profiler/tests/jfluid/ProfilerStableTestSuite.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2008 Sun Microsystems, Inc.
 */

package org.netbeans.lib.profiler.tests.jfluid;

import junit.framework.Test;
import org.netbeans.junit.NbModuleSuite;

/**
 *
 * @author tester
 */
public class ProfilerStableTestSuite {
    public static Test suite() {
    return NbModuleSuite.create(
      NbModuleSuite.emptyConfiguration()
        .addTest(org.netbeans.lib.profiler.tests.jfluid.BasicTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.perf.InstrumentationTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.wireio.BasicTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.monitor.BasicTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.memory.BasicTest.class)
	.addTest(org.netbeans.lib.profiler.tests.jfluid.memory.MemorySnapshotTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.others.MeasureDiffsTest.class)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.CPUSnapshotTest.class)
	.addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.class, org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.tests)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.class, org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.tests2)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.class, org.netbeans.lib.profiler.tests.jfluid.cpu.BasicTest.tests3)
        .addTest(org.netbeans.lib.profiler.tests.jfluid.benchmarks.JbbTest.class)
    );
  }


}
